@@ -173,7 +173,6 @@ g_output_stream_write (GOutputStream *stream,
   gssize res;
 
   g_return_val_if_fail (G_IS_OUTPUT_STREAM (stream), -1);
-  g_return_val_if_fail (stream != NULL, -1);
   g_return_val_if_fail (buffer != NULL, 0);
 
   if (count == 0)
@@ -228,7 +227,7 @@ g_output_stream_write (GOutputStream *stream,
  * @buffer: the buffer containing the data to write. 
  * @count: the number of bytes to write
  * @bytes_written: location to store the number of bytes that was written to the stream
- * @cancellable: optional cancellable object
+ * @cancellable: optional #GCancellable object, %NULL to ignore.
  * @error: location to store the error occuring, or %NULL to ignore
  *
  * Tries to write @count bytes from @buffer into the stream. Will block
@@ -237,14 +236,14 @@ g_output_stream_write (GOutputStream *stream,
  * This function is similar to g_output_stream_write(), except it tries to
  * read as many bytes as requested, only stopping on an error.
  *
- * On a successful write of @count bytes, TRUE is returned, and @bytes_written
+ * On a successful write of @count bytes, %TRUE is returned, and @bytes_written
  * is set to @count.
  * 
  * If there is an error during the operation FALSE is returned and @error
  * is set to indicate the error status, @bytes_written is updated to contain
  * the number of bytes written into the stream before the error occured.
  *
- * Return value: TRUE on success, FALSE if there was an error
+ * Return value: %TRUE on success, %FALSE if there was an error
  **/
 gboolean
 g_output_stream_write_all (GOutputStream *stream,
@@ -257,6 +256,9 @@ g_output_stream_write_all (GOutputStream *stream,
   gsize _bytes_written;
   gssize res;
 
+  g_return_val_if_fail (G_IS_OUTPUT_STREAM (stream), FALSE);
+  g_return_val_if_fail (buffer != NULL, FALSE);
+
   _bytes_written = 0;
   while (_bytes_written < count)
     {
@@ -306,7 +308,6 @@ g_output_stream_flush (GOutputStream    *stream,
   gboolean res;
 
   g_return_val_if_fail (G_IS_OUTPUT_STREAM (stream), FALSE);
-  g_return_val_if_fail (stream != NULL, FALSE);
 
   if (stream->priv->closed)
     {
@@ -346,9 +347,11 @@ g_output_stream_flush (GOutputStream    *stream,
  * @stream:
  * @source:
  * @flags:
- * @cancellable:
- * @error:
- * 
+ * @cancellable: optional #GCancellable object, %NULL to ignore. 
+ * @error: a #GError location to store the error occuring, or %NULL to 
+ * ignore.
+ *
+ *
  * Returns: 
  **/
 gssize
@@ -362,8 +365,7 @@ g_output_stream_splice (GOutputStream *stream,
   gboolean res;
 
   g_return_val_if_fail (G_IS_OUTPUT_STREAM (stream), -1);
-  g_return_val_if_fail (stream != NULL, -1);
-  g_return_val_if_fail (source != NULL, -1);
+  g_return_val_if_fail (G_IS_INPUT_STREAM (source), -1);
 
   if (stream->priv->closed)
     {
@@ -502,7 +504,7 @@ g_output_stream_real_splice (GOutputStream *stream,
  * 
  * If @cancellable is not NULL, then the operation can be cancelled by
  * triggering the cancellable object from another thread. If the operation
- * was cancelled, the error G_IO_ERROR_CANCELLED will be returned.
+ * was cancelled, the error %G_IO_ERROR_CANCELLED will be returned.
  * Cancelling a close will still leave the stream closed, but there some streams
  * can use a faster close that doesn't block to e.g. check errors. On
  * cancellation (as with any error) there is no guarantee that all written
@@ -518,8 +520,7 @@ g_output_stream_close (GOutputStream  *stream,
   GOutputStreamClass *class;
   gboolean res;
 
-  g_return_val_if_fail (G_IS_OUTPUT_STREAM (stream), -1);
-  g_return_val_if_fail (stream != NULL, -1);
+  g_return_val_if_fail (G_IS_OUTPUT_STREAM (stream), FALSE);
 
   class = G_OUTPUT_STREAM_GET_CLASS (stream);
 
@@ -596,10 +597,10 @@ async_ready_close_callback_wrapper (GObject *source_object,
  * @stream: A #GOutputStream.
  * @buffer: the buffer containing the data to write. 
  * @count: the number of bytes to write
- * @io_priority: the io priority of the request
+ * @io_priority: the io priority of the request. the io priority of the request
+ * @cancellable: optional #GCancellable object, %NULL to ignore.
  * @callback: callback to call when the request is satisfied
  * @user_data: the data to pass to callback function
- * @cancellable: optional cancellable object
  *
  * Request an asynchronous write of @count bytes from @buffer into the stream.
  * When the operation is finished @callback will be called, giving the results.
@@ -610,17 +611,19 @@ async_ready_close_callback_wrapper (GObject *source_object,
  * A value of @count larger than %G_MAXSSIZE will cause a %G_IO_ERROR_INVALID_ARGUMENT error.
  *
  * On success, the number of bytes written will be passed to the
- * callback. It is not an error if this is not the same as the requested size, as it
+ * @callback. It is not an error if this is not the same as the requested size, as it
  * can happen e.g. on a partial i/o error, but generally we try to write
  * as many bytes as requested. 
  *
  * Any outstanding i/o request with higher priority (lower numerical value) will
  * be executed before an outstanding request with lower priority. Default
- * priority is G_%PRIORITY_DEFAULT.
+ * priority is %G_PRIORITY_DEFAULT.
  *
  * The asyncronous methods have a default fallback that uses threads to implement
  * asynchronicity, so they are optional for inheriting classes. However, if you
  * override one you must override all.
+ *
+ * For the synchronous, blocking version of this function, see g_output_stream_write().
  **/
 void
 g_output_stream_write_async (GOutputStream       *stream,
@@ -635,7 +638,6 @@ g_output_stream_write_async (GOutputStream       *stream,
   GSimpleAsyncResult *simple;
 
   g_return_if_fail (G_IS_OUTPUT_STREAM (stream));
-  g_return_if_fail (stream != NULL);
   g_return_if_fail (buffer != NULL);
 
   if (count == 0)
@@ -690,9 +692,11 @@ g_output_stream_write_async (GOutputStream       *stream,
 
 /**
  * g_output_stream_write_finish:
- * @stream:
- * @result:
- * @error:
+ * @stream: a #GOutputStream.
+ * @result: a #GAsyncResult.
+ * @error: a #GError location to store the error occuring, or %NULL to 
+ * ignore.
+ * 
  * 
  * Returns: 
  **/
@@ -704,6 +708,9 @@ g_output_stream_write_finish (GOutputStream *stream,
   GSimpleAsyncResult *simple;
   GOutputStreamClass *class;
 
+  g_return_val_if_fail (G_IS_OUTPUT_STREAM (stream), -1);
+  g_return_val_if_fail (G_IS_ASYNC_RESULT (result), -1);
+
   if (G_IS_SIMPLE_ASYNC_RESULT (result))
     {
       simple = G_SIMPLE_ASYNC_RESULT (result);
@@ -748,8 +755,8 @@ async_ready_splice_callback_wrapper (GObject *source_object,
  * @stream:
  * @source:
  * @flags:
- * @io_priority:
- * @cancellable:
+ * @io_priority: the io priority of the request.
+ * @cancellable: optional #GCancellable object, %NULL to ignore. 
  * @callback:
  * @user_data:
  * 
@@ -767,8 +774,7 @@ g_output_stream_splice_async (GOutputStream             *stream,
   SpliceUserData *data;
 
   g_return_if_fail (G_IS_OUTPUT_STREAM (stream));
-  g_return_if_fail (stream != NULL);
-  g_return_if_fail (source != NULL);
+  g_return_if_fail (G_IS_INPUT_STREAM (source));
 
   if (stream->priv->closed)
     {
@@ -816,10 +822,11 @@ g_output_stream_splice_async (GOutputStream             *stream,
 
 /**
  * g_output_stream_splice_finish:
- * @stream:
- * @result:
- * @error:
- * 
+ * @stream: a #GOutputStream.
+ * @result: a #GAsyncResult.
+ * @error: a #GError location to store the error occuring, or %NULL to 
+ * ignore.
+ *
  * Returns: 
  **/
 gssize
@@ -830,6 +837,9 @@ g_output_stream_splice_finish (GOutputStream             *stream,
   GSimpleAsyncResult *simple;
   GOutputStreamClass *class;
 
+  g_return_val_if_fail (G_IS_OUTPUT_STREAM (stream), -1);
+  g_return_val_if_fail (G_IS_ASYNC_RESULT (result), -1);
+
   if (G_IS_SIMPLE_ASYNC_RESULT (result))
     {
       simple = G_SIMPLE_ASYNC_RESULT (result);
@@ -844,9 +854,9 @@ g_output_stream_splice_finish (GOutputStream             *stream,
 /**
  * g_output_stream_flush_async:
  * @stream:
- * @io_priority:
- * @cancellable:
- * @callback:
+ * @io_priority: the io priority of the request.
+ * @cancellable: optional #GCancellable object, %NULL to ignore.
+ * @callback: a #GAsyncReadyCallback.
  * @user_data:
  * 
  **/
@@ -861,7 +871,6 @@ g_output_stream_flush_async (GOutputStream       *stream,
   GSimpleAsyncResult *simple;
 
   g_return_if_fail (G_IS_OUTPUT_STREAM (stream));
-  g_return_if_fail (stream != NULL);
 
   if (stream->priv->closed)
     {
@@ -905,11 +914,11 @@ g_output_stream_flush_async (GOutputStream       *stream,
 
 /**
  * g_output_stream_flush_finish:
- * @stream:
- * @result:
- * @error:
- * 
- * Returns: %TRUE, %FALSE otherwise.
+ * @stream: a #GOutputStream.
+ * @result: a GAsyncResult.
+ * @error: a #GError location to store the error occuring, or %NULL to 
+ * ignore.
+ * Returns: %TRUE if flush operation suceeded, %FALSE otherwise.
  **/
 gboolean
 g_output_stream_flush_finish (GOutputStream *stream,
@@ -919,6 +928,9 @@ g_output_stream_flush_finish (GOutputStream *stream,
   GSimpleAsyncResult *simple;
   GOutputStreamClass *klass;
 
+  g_return_val_if_fail (G_IS_OUTPUT_STREAM (stream), FALSE);
+  g_return_val_if_fail (G_IS_ASYNC_RESULT (result), FALSE);
+
   if (G_IS_SIMPLE_ASYNC_RESULT (result))
     {
       simple = G_SIMPLE_ASYNC_RESULT (result);
@@ -962,7 +974,6 @@ g_output_stream_close_async (GOutputStream      *stream,
   GSimpleAsyncResult *simple;
 
   g_return_if_fail (G_IS_OUTPUT_STREAM (stream));
-  g_return_if_fail (stream != NULL);
   
   if (stream->priv->closed)
     {
@@ -997,8 +1008,8 @@ g_output_stream_close_async (GOutputStream      *stream,
  * g_output_stream_close_finish:
  * @stream:
  * @result:
- * @error:
- * 
+ * @error: a #GError location to store the error occuring, or %NULL to 
+ * ignore.
  * Returns: %TRUE, %FALSE otherwise.
  **/
 gboolean
@@ -1009,6 +1020,9 @@ g_output_stream_close_finish (GOutputStream *stream,
   GSimpleAsyncResult *simple;
   GOutputStreamClass *class;
 
+  g_return_val_if_fail (G_IS_OUTPUT_STREAM (stream), FALSE);
+  g_return_val_if_fail (G_IS_ASYNC_RESULT (result), FALSE);
+
   if (G_IS_SIMPLE_ASYNC_RESULT (result))
     {
       simple = G_SIMPLE_ASYNC_RESULT (result);
@@ -1034,7 +1048,6 @@ gboolean
 g_output_stream_is_closed (GOutputStream *stream)
 {
   g_return_val_if_fail (G_IS_OUTPUT_STREAM (stream), TRUE);
-  g_return_val_if_fail (stream != NULL, TRUE);
   
   return stream->priv->closed;
 }
@@ -1048,8 +1061,7 @@ g_output_stream_is_closed (GOutputStream *stream)
 gboolean
 g_output_stream_has_pending (GOutputStream *stream)
 {
-  g_return_val_if_fail (G_IS_OUTPUT_STREAM (stream), TRUE);
-  g_return_val_if_fail (stream != NULL, TRUE);
+  g_return_val_if_fail (G_IS_OUTPUT_STREAM (stream), FALSE);
   
   return stream->priv->pending;
 }
@@ -1067,7 +1079,6 @@ g_output_stream_set_pending (GOutputStream              *stream,
 			    gboolean                   pending)
 {
   g_return_if_fail (G_IS_OUTPUT_STREAM (stream));
-  g_return_if_fail (stream != NULL);
   
   stream->priv->pending = pending;
 }
